@@ -10,7 +10,7 @@ from .context import resolve_context
 from .resource import resource
 from .url_tree import ClassURLWriter, SimpleURLWriter, URLTreeVisitor
 
-VERSION = (1, 1, 0)
+VERSION = (1, 1, 2)
 
 __title__ = 'Django Render Static'
 __version__ = '.'.join(str(i) for i in VERSION)
@@ -20,3 +20,15 @@ __copyright__ = 'Copyright 2020-2021 Brian Kohan'
 
 
 default_app_config = 'render_static.apps.RenderStaticConfig'  # pylint: disable=C0103
+
+
+class Jinja2DependencyNeeded:  # pylint: disable=R0903
+    """
+    Jinja2 is an optional dependency - lazy fail if its use is attempted without it being
+    present on the python path.
+    """
+
+    def __init__(self, *args, **kwargs):
+        raise ImportError(  # pragma: no cover
+            'To use the Jinja2 backend you must install the Jinja2 python package.'
+        )
